@@ -1,9 +1,11 @@
 from rest_framework import serializers
 
+from dcim.api.nested_serializers import NestedPlatformSerializer
 from netbox.api.serializers import NetBoxModelSerializer
 from netbox_storage.api.nested_serializers import NestedFilesystemSerializer, NestedDriveSerializer, \
     NestedPartitionSerializer, NestedMountedVolumeSerializer
-from netbox_storage.models import Drive, Filesystem, Partition, MountedVolume, StorageConfigurationLinuxVolume
+from netbox_storage.models import Drive, Filesystem, Partition, MountedVolume, StorageConfigurationLinuxVolume, \
+    LinuxDevice, TemplateConfigurationLinuxVolume
 from virtualization.api.nested_serializers import NestedClusterSerializer, NestedVirtualMachineSerializer
 
 
@@ -84,13 +86,12 @@ class LinuxDeviceSerializer(serializers.ModelSerializer):
     drive = NestedDriveSerializer(required=False, allow_null=True)
 
     class Meta:
-        model = MountedVolume
+        model = LinuxDevice
         fields = (
             "id",
             "drive",
             "device",
             "size",
-            "path",
             "type",
             "description",
             "created",
@@ -113,3 +114,19 @@ class StorageConfigurationLinuxVolumeSerializer(serializers.ModelSerializer):
             "last_updated",
             "custom_fields",
         )
+
+
+class TemplateConfigurationLinuxVolumeSerializer(serializers.ModelSerializer):
+    linux_volume = NestedMountedVolumeSerializer(required=False, allow_null=True)
+    platform = NestedPlatformSerializer(required=False, allow_null=True)
+
+    class Meta:
+        model = TemplateConfigurationLinuxVolume
+        fields = (
+            "id",
+            "platform",
+            "linux_volume",
+            "created",
+            "last_updated",
+            "custom_fields",
+        )
