@@ -15,16 +15,10 @@ class DriveFilter(NetBoxModelFilterSet):
         to_field_name='name',
         label='Cluster',
     )
-    storage_configuration = django_filters.ModelMultipleChoiceFilter(
-        field_name='storage_configuration__name',
-        queryset=VirtualMachine.objects.all(),
-        to_field_name='name',
-        label='storage_configuration (name)',
-    )
 
     class Meta:
         model = Drive
-        fields = ("size", "cluster", "identifier", "storage_configuration", "description",)
+        fields = ("size", "cluster", "identifier", "description",)
 
     def search(self, queryset, name, value):
         """Perform the filtered search."""
