@@ -199,7 +199,8 @@ class LinuxVolumeSimpleForm(NetBoxModelForm):
     def save(self, *args, **kwargs):
 
         drive = Drive.objects.create(cluster=self.cleaned_data['cluster'], size=self.cleaned_data['size'])
-        linux_device = LinuxDevice.objects.create(drive=drive, device=drive.device_name(), size=self.cleaned_data['size'], type='disk')
+        linux_device = LinuxDevice.objects.create(drive=drive, device=drive.device_name(),
+                                                  size=self.cleaned_data['size'], type='disk')
 
         # partition = Partition.objects.create(drive=drive, device=drive.device_name(), size=self.cleaned_data['size'],
         #                                      type='Linux', description='Partition 1 on SSD Cluster')
