@@ -1,7 +1,8 @@
 import logging
 
 from extras.plugins import PluginTemplateExtension
-from netbox_storage.models import PhysicalVolume, LogicalVolume, MountedVolume, StorageConfigurationLinuxVolume
+from netbox_storage.models import PhysicalVolume, LogicalVolume, MountedVolume, StorageConfigurationLinuxVolume, \
+    TemplateConfigurationLinuxVolume
 
 
 class RelatedDrives(PluginTemplateExtension):
@@ -46,13 +47,15 @@ class TemplateVolumeConfig(PluginTemplateExtension):
         obj = self.context.get("object")
 
         lv = LogicalVolume.objects.all()
+        template_linux_volumes = TemplateConfigurationLinuxVolume.objects.filter(platform=obj)
+
 
         # storage_configuration = StorageConfigurationLinuxVolume.objects.filter(virtual_machine=obj)
 
         return self.render(
             "netbox_storage/inc/template_box.html",
             extra_context={
-                "lv": lv,
+                "template_linux_volumes": template_linux_volumes,
             }
         )
 
